@@ -13,7 +13,8 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+  USA.
 */
 
 #ifndef AUDIOCD_ENCODER_H
@@ -21,10 +22,10 @@
 
 #include "audiocdplugins_export.h"
 
-#include <sys/types.h>
 #include <KIO/SlaveBase>
 #include <QList>
 #include <QLoggingCategory>
+#include <sys/types.h>
 
 #include <KCddb/Cdinfo>
 
@@ -36,18 +37,23 @@ using namespace KCDDB;
 class AUDIOCDPLUGINS_EXPORT AudioCDEncoder {
 
 public:
-  /**
-   * Constructor.
-   * @param slave parent that this classes can use to call data() with
-   * when finished encoding bits.
-   */ 
-  explicit AudioCDEncoder(KIO::SlaveBase *slave) : ioslave(slave) {}
-  
+    /**
+     * Constructor.
+     * @param slave parent that this classes can use to call data() with
+     * when finished encoding bits.
+     */
+    explicit AudioCDEncoder(KIO::SlaveBase *slave)
+        : ioslave(slave)
+    {
+    }
+
   /**
    * Destructor.
    */
-  virtual ~AudioCDEncoder(){}
-  
+    virtual ~AudioCDEncoder()
+    {
+    }
+
   /**
    * Initializes the decoder, loading libraries, etc.  Encoders
    * that don't return true will will deleted and not used.
@@ -57,7 +63,7 @@ public:
 
   /**
    * The encoder should read in its config data here.
-   */ 
+   */
   virtual void loadSettings() = 0;
 
   /**
@@ -65,44 +71,44 @@ public:
    * encoded file.
    * @param time_secs the length of the audio track in seconds.
    * @returns the size of a file if it is time_secs in length.
-   */ 
+   */
   virtual unsigned long size(long time_secs) const = 0;
 
   /**
    * @returns the generic user string type/name of this encoder
    * Examples: "MP3", "Ogg Vorbis", "Wav", "FID Level 2", etc
-   */ 
+   */
   virtual QString type() const = 0;
-  
+
   /**
    * @returns the mime type for the files this encoder produces.
    * Example: "audio/x-wav"
-   */ 
-  virtual const char * mimeType() const = 0;
+   */
+  virtual const char *mimeType() const = 0;
 
   /**
    * @returns the file type for the files this encoder produces.
    * Used in naming of the file for example foo.mp3
    * Examples: "mp3", "ogg", "wav"
-   */ 
-  virtual const char * fileType() const = 0;
+   */
+  virtual const char *fileType() const = 0;
 
   /**
-   * Before the read functions are called this is 
+   * Before the read functions are called this is
    * called to allow the encoders to store the cddb
-   * information if they want to so it can be inserted 
+   * information if they want to so it can be inserted
    * where necessary (start, middle, end, or combos etc).
-   */ 
-  virtual void fillSongInfo( KCDDB::CDInfo info, int track, const QString &comment ) = 0;
-  
+   */
+  virtual void fillSongInfo(KCDDB::CDInfo info, int track, const QString &comment) = 0;
+
   /**
    * Perform any initial file creation necessary for a new song (that
    * has just been sent via fillSongInfo())
    * @param size - the total binary size of the end file (via size()).
    * @return size of the data that was created by this function.
-   */ 
+   */
   virtual long readInit(long size) = 0;
-  
+
   /**
    * Passes a little bit of cd data to be encoded
    * This function is most likely called many many times.
@@ -110,20 +116,23 @@ public:
    * @param frames the number of frames of audio that are in @p buf
    * @return size of the data that was created by this function, -1 on error.
    */
-  virtual long read(qint16 * buf, int frames) = 0;
+  virtual long read(qint16 *buf, int frames) = 0;
 
   /**
    * Perform any final file creation/padding that is necessary
    * @return size of the data that was created by this function.
-   */ 
+   */
   virtual long readCleanup() = 0;
 
   /**
    * Returns a configure widget for the encoder
-   */ 
-  virtual QWidget* getConfigureWidget(KConfigSkeleton** manager) const
-                   { Q_UNUSED(manager); return nullptr; }
- 
+   */
+  virtual QWidget *getConfigureWidget(KConfigSkeleton **manager) const
+  {
+      Q_UNUSED(manager);
+      return nullptr;
+  }
+
   /**
    * Returns the last error message; called when e.g. read() returns -1.
    */
@@ -132,21 +141,20 @@ public:
   /**
    * Helper function to load all of the AudioCD Encoders from libraries.
    * Uses QLibraryInfo to find where libraries could be, opens all of the ones
-   * that we might own audiocd_encoder_* and then uses the symbol 
+   * that we might own audiocd_encoder_* and then uses the symbol
    * create_audiocd_encoders to obtain the encoders from that library.
-   * @param slave ioslave needed if the plugin is going to be used to encode something.
+   * @param slave ioslave needed if the plugin is going to be used to encode
+   * something.
    * @param encoders container for new encoders.
    */
-  static void findAllPlugins(KIO::SlaveBase *slave, QList<AudioCDEncoder*> &encoders);
+  static void findAllPlugins(KIO::SlaveBase *slave, QList<AudioCDEncoder *> &encoders);
 
-protected:
+  protected:
   /**
    * Pointer to the ioslave that is running this encoder.
    * Used (only?) for the data() function to pass back encoded data.
    */
   KIO::SlaveBase *ioslave;
-
 };
 
 #endif // AUDIOCD_ENCODER_H
-
