@@ -19,16 +19,17 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+  USA.
 */
 
 #ifndef ENCODER_WAV_H
 #define ENCODER_WAV_H
 
 #include "encodercda.h"
+#include <cstdlib>
 #include <sys/stat.h>
 #include <unistd.h>
-#include <cstdlib>
 
 /**
  * Wav audio "encoder"
@@ -38,15 +39,24 @@ class EncoderWav : public EncoderCda {
 
 public:
   explicit EncoderWav(KIO::SlaveBase *slave) : EncoderCda(slave) {}
-  ~EncoderWav(){}
+  ~EncoderWav()
+  {
+  }
   virtual bool init() override { return true; }
   virtual unsigned long size(long time_secs) const override;
-  virtual QString type() const override { return QLatin1String( "Wav" ); }
-  virtual const char * fileType() const override { return "wav"; }
-  virtual const char * mimeType() const override;
-  virtual void fillSongInfo( KCDDB::CDInfo, int, const QString &) override {}
+  virtual QString type() const override
+  {
+      return QLatin1String("Wav");
+  }
+  virtual const char *fileType() const override
+  {
+      return "wav";
+  }
+  virtual const char *mimeType() const override;
+  virtual void fillSongInfo(KCDDB::CDInfo, int, const QString &) override
+  {
+  }
   virtual long readInit(long size) override;
-
 };
 
 #endif // ENCODER_WAV_H
